@@ -22,7 +22,7 @@ namespace eval ::tdbc {
 #
 # tdbc::ParseConvenienceArgs --
 #
-#	Parse the convenience arguments to a TDBC 'execute', 
+#	Parse the convenience arguments to a TDBC 'execute',
 #	'executewithdictionary', or 'foreach' call.
 #
 # Parameters:
@@ -45,9 +45,9 @@ proc tdbc::ParseConvenienceArgs {argv optsVar} {
 
     set opts [dict create -as dicts]
     set i 0
-    
+
     # Munch keyword options off the front of the command arguments
-    
+
     foreach {key value} $argv {
 	if {[string index $key 0] eq {-}} {
 	    switch -regexp -- $key {
@@ -58,7 +58,7 @@ proc tdbc::ParseConvenienceArgs {argv optsVar} {
 			return -code error \
 			    -errorcode $errorcode \
 			    "bad variable type \"$value\":\
-                             must be lists or dicts"
+			     must be lists or dicts"
 		    }
 		    dict set opts -as $value
 		}
@@ -75,7 +75,7 @@ proc tdbc::ParseConvenienceArgs {argv optsVar} {
 		    return -code error \
 			-errorcode $errorcode \
 			"bad option \"$key\":\
-                             must be -as or -columnsvariable"
+			must be -as or -columnsvariable"
 		}
 	    }
 	} else {
@@ -85,7 +85,7 @@ proc tdbc::ParseConvenienceArgs {argv optsVar} {
     }
 
     return [lrange $argv[set argv {}] $i end]
-    
+
 }
 
 
@@ -150,7 +150,7 @@ oo::class create ::tdbc::connection {
     # and have it call 'prepare' as needed (or do something else and
     # install the resulting statement)
 
-    # The 'statements' method lists the statements active against this 
+    # The 'statements' method lists the statements active against this
     # connection.
 
     method statements {} {
@@ -215,7 +215,7 @@ oo::class create ::tdbc::connection {
 
 	set args [::tdbc::ParseConvenienceArgs $args[set args {}] opts]
 
-	# Check postitional parameters 
+	# Check postitional parameters
 
 	set cmd [list [self] prepare]
 	if {[llength $args] == 1} {
@@ -227,7 +227,7 @@ oo::class create ::tdbc::connection {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? sqlcode ?dictionary?"
+		 ?-option value?... ?--? sqlcode ?dictionary?"
 	}
 	lappend cmd $sqlcode
 
@@ -259,7 +259,7 @@ oo::class create ::tdbc::connection {
     # it sets a variable to the row and invokes a script in the caller's
     # scope.
     #
-    # Usage: 
+    # Usage:
     #     $db foreach ?-as lists|dicts? ?-columnsVariable varName? ?--?
     #         varName sql ?dictionary? script
 
@@ -271,7 +271,7 @@ oo::class create ::tdbc::connection {
 
 	set args [::tdbc::ParseConvenienceArgs $args[set args {}] opts]
 
-	# Check postitional parameters 
+	# Check postitional parameters
 
 	set cmd [list [self] prepare]
 	if {[llength $args] == 3} {
@@ -283,7 +283,7 @@ oo::class create ::tdbc::connection {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? varname sqlcode ?dictionary? script"
+		 ?-option value?... ?--? varname sqlcode ?dictionary? script"
 	}
 	lappend cmd $sqlcode
 
@@ -330,29 +330,29 @@ oo::class create ::tdbc::connection {
 
 	set catalogClause {}
 	if {[lindex [set count [my allrows -as lists {
-	    SELECT COUNT(*) 
-            FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
-            WHERE CONSTRAINT_CATALOG IS NOT NULL}]] 0 0] != 0} {
+	    SELECT COUNT(*)
+	    FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
+	    WHERE CONSTRAINT_CATALOG IS NOT NULL}]] 0 0] != 0} {
 	    set catalogClause \
 		{AND xtable.CONSTRAINT_CATALOG = xcolumn.CONSTRAINT_CATALOG}
 	}
 	set primaryKeysStatement [my prepare "
-	     SELECT xtable.TABLE_SCHEMA AS \"tableSchema\", 
-                 xtable.TABLE_NAME AS \"tableName\",
-                 xtable.CONSTRAINT_CATALOG AS \"constraintCatalog\", 
-                 xtable.CONSTRAINT_SCHEMA AS \"constraintSchema\", 
-                 xtable.CONSTRAINT_NAME AS \"constraintName\", 
-                 xcolumn.COLUMN_NAME AS \"columnName\", 
-                 xcolumn.ORDINAL_POSITION AS \"ordinalPosition\" 
-             FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS xtable 
-             INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE xcolumn 
-                     ON xtable.CONSTRAINT_SCHEMA = xcolumn.CONSTRAINT_SCHEMA 
-                    AND xtable.TABLE_NAME = xcolumn.TABLE_NAME
-                    AND xtable.CONSTRAINT_NAME = xcolumn.CONSTRAINT_NAME 
-	            $catalogClause
-             WHERE xtable.TABLE_NAME = :tableName 
-               AND xtable.CONSTRAINT_TYPE = 'PRIMARY KEY'
-  	"]
+	     SELECT xtable.TABLE_SCHEMA AS \"tableSchema\",
+		 xtable.TABLE_NAME AS \"tableName\",
+		 xtable.CONSTRAINT_CATALOG AS \"constraintCatalog\",
+		 xtable.CONSTRAINT_SCHEMA AS \"constraintSchema\",
+		 xtable.CONSTRAINT_NAME AS \"constraintName\",
+		 xcolumn.COLUMN_NAME AS \"columnName\",
+		 xcolumn.ORDINAL_POSITION AS \"ordinalPosition\"
+	     FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS xtable
+	     INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE xcolumn
+		     ON xtable.CONSTRAINT_SCHEMA = xcolumn.CONSTRAINT_SCHEMA
+		    AND xtable.TABLE_NAME = xcolumn.TABLE_NAME
+		    AND xtable.CONSTRAINT_NAME = xcolumn.CONSTRAINT_NAME
+		    $catalogClause
+	     WHERE xtable.TABLE_NAME = :tableName
+	       AND xtable.CONSTRAINT_TYPE = 'PRIMARY KEY'
+	"]
     }
 
     # The default implementation of the 'primarykeys' method uses the
@@ -380,9 +380,9 @@ oo::class create ::tdbc::connection {
 	set catalogClause1 {}
 	set catalogClause2 {}
 	if {[lindex [set count [my allrows -as lists {
-	    SELECT COUNT(*) 
-            FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
-            WHERE CONSTRAINT_CATALOG IS NOT NULL}]] 0 0] != 0} {
+	    SELECT COUNT(*)
+	    FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
+	    WHERE CONSTRAINT_CATALOG IS NOT NULL}]] 0 0] != 0} {
 	    set catalogClause1 \
 		{AND fkc.CONSTRAINT_CATALOG = rc.CONSTRAINT_CATALOG}
 	    set catalogClause2 \
@@ -399,36 +399,37 @@ oo::class create ::tdbc::connection {
 	    } {
 		set stmt [my prepare "
 	     SELECT rc.CONSTRAINT_CATALOG AS \"foreignConstraintCatalog\",
-                    rc.CONSTRAINT_SCHEMA AS \"foreignConstraintSchema\",
-                    rc.CONSTRAINT_NAME AS \"foreignConstraintName\",
-                    rc.UNIQUE_CONSTRAINT_CATALOG 
-                        AS \"primaryConstraintCatalog\",
-                    rc.UNIQUE_CONSTRAINT_SCHEMA AS \"primaryConstraintSchema\",
-                    rc.UNIQUE_CONSTRAINT_NAME AS \"primaryConstraintName\",
-                    rc.UPDATE_RULE AS \"updateAction\",
+		    rc.CONSTRAINT_SCHEMA AS \"foreignConstraintSchema\",
+		    rc.CONSTRAINT_NAME AS \"foreignConstraintName\",
+		    rc.UNIQUE_CONSTRAINT_CATALOG
+			AS \"primaryConstraintCatalog\",
+		    rc.UNIQUE_CONSTRAINT_SCHEMA AS \"primaryConstraintSchema\",
+		    rc.UNIQUE_CONSTRAINT_NAME AS \"primaryConstraintName\",
+		    rc.UPDATE_RULE AS \"updateAction\",
 		    rc.DELETE_RULE AS \"deleteAction\",
-                    pkc.TABLE_CATALOG AS \"primaryCatalog\",
-                    pkc.TABLE_SCHEMA AS \"primarySchema\",
-                    pkc.TABLE_NAME AS \"primaryTable\",
-                    pkc.COLUMN_NAME AS \"primaryColumn\",
-                    fkc.TABLE_CATALOG AS \"foreignCatalog\",
-                    fkc.TABLE_SCHEMA AS \"foreignSchema\",
-                    fkc.TABLE_NAME AS \"foreignTable\",
-                    fkc.COLUMN_NAME AS \"foreignColumn\",
-                    pkc.ORDINAL_POSITION AS \"ordinalPosition\"
-             FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS rc
-             INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE fkc
-                     ON fkc.CONSTRAINT_NAME = rc.CONSTRAINT_NAME
-                    AND fkc.CONSTRAINT_SCHEMA = rc.CONSTRAINT_SCHEMA
-                    $catalogClause1
-             INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE pkc
-                     ON pkc.CONSTRAINT_NAME = rc.UNIQUE_CONSTRAINT_NAME
-                     AND pkc.CONSTRAINT_SCHEMA = rc.UNIQUE_CONSTRAINT_SCHEMA
-                     $catalogClause2
-                     AND pkc.ORDINAL_POSITION = fkc.ORDINAL_POSITION
-             WHERE 1=1
-                 $clause1
-                 $clause2
+		    pkc.TABLE_CATALOG AS \"primaryCatalog\",
+		    pkc.TABLE_SCHEMA AS \"primarySchema\",
+		    pkc.TABLE_NAME AS \"primaryTable\",
+		    pkc.COLUMN_NAME AS \"primaryColumn\",
+		    fkc.TABLE_CATALOG AS \"foreignCatalog\",
+		    fkc.TABLE_SCHEMA AS \"foreignSchema\",
+		    fkc.TABLE_NAME AS \"foreignTable\",
+		    fkc.COLUMN_NAME AS \"foreignColumn\",
+		    pkc.ORDINAL_POSITION AS \"ordinalPosition\"
+	     FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS rc
+	     INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE fkc
+		     ON fkc.CONSTRAINT_NAME = rc.CONSTRAINT_NAME
+		    AND fkc.CONSTRAINT_SCHEMA = rc.CONSTRAINT_SCHEMA
+		    $catalogClause1
+	     INNER JOIN INFORMATION_SCHEMA.KEY_COLUMN_USAGE pkc
+		     ON pkc.CONSTRAINT_NAME = rc.UNIQUE_CONSTRAINT_NAME
+		     AND pkc.CONSTRAINT_SCHEMA = rc.UNIQUE_CONSTRAINT_SCHEMA
+		     $catalogClause2
+		     AND pkc.ORDINAL_POSITION = fkc.ORDINAL_POSITION
+	     WHERE 1=1
+		 $clause1
+		 $clause2
+	     ORDER BY \"foreignConstraintCatalog\", \"foreignConstraintSchema\", \"foreignConstraintName\", \"ordinalPosition\"
 "]
 		dict set foreignKeysStatement $exists1 $exists2 $stmt
 	    }
@@ -451,7 +452,7 @@ oo::class create ::tdbc::connection {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?..."
+		 ?-option value?..."
 	}
 	foreach {key value} $args {
 	    if {$key ni {-primary -foreign}} {
@@ -485,7 +486,7 @@ oo::class create ::tdbc::connection {
 
     # Derived classes are expected to implement the 'begintransaction',
     # 'commit', and 'rollback' methods.
-	
+
     # Derived classes are expected to implement 'tables' and 'columns' method.
 
 }
@@ -524,7 +525,7 @@ oo::class create tdbc::statement {
     # is wrapped in an [uplevel] call because the substitution proces
     # may need to access variables in the caller's scope.
 
-    # WORKAROUND: Take out the '0 &&' from the next line when 
+    # WORKAROUND: Take out the '0 &&' from the next line when
     # Bug 2649975 is fixed
     if {0 && [package vsatisfies [package provide Tcl] 8.6]} {
 	method execute args {
@@ -578,7 +579,7 @@ oo::class create tdbc::statement {
 
 	set args [::tdbc::ParseConvenienceArgs $args[set args {}] opts]
 
-	# Check postitional parameters 
+	# Check postitional parameters
 
 	set cmd [list [self] execute]
 	if {[llength $args] == 0} {
@@ -590,7 +591,7 @@ oo::class create tdbc::statement {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? ?dictionary?"
+		 ?-option value?... ?--? ?dictionary?"
 	}
 
 	# Get the result set
@@ -636,7 +637,7 @@ oo::class create tdbc::statement {
 	# Grab keyword-value parameters
 
 	set args [::tdbc::ParseConvenienceArgs $args[set args {}] opts]
-	
+
 	# Check positional parameters
 
 	set cmd [list [self] execute]
@@ -650,7 +651,7 @@ oo::class create tdbc::statement {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? varName ?dictionary? script"
+		 ?-option value?... ?--? varName ?dictionary? script"
 	}
 
 	# Get the result set
@@ -721,7 +722,7 @@ oo::class create tdbc::resultset {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? varName script"
+		 ?-option value?... ?--? varName script"
 	}
 
 	# Do -columnsvariable if requested
@@ -746,7 +747,7 @@ oo::class create tdbc::resultset {
 	    if {![my nextresults]} break
 	}
 	return $results
-	    
+
     }
 
     # The 'foreach' method runs a script on each row from a result set.
@@ -766,16 +767,16 @@ oo::class create tdbc::resultset {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? varName script"
+		 ?-option value?... ?--? varName script"
 	}
 
 	# Do -columnsvariable if requested
-	    
+
 	if {[dict exists $opts -columnsvariable]} {
 	    upvar 1 [dict get $opts -columnsvariable] columns
 	}
 
-	# Iterate over the groups of results 
+	# Iterate over the groups of results
 	while {1} {
 
 	    # Export column names to caller
@@ -818,12 +819,12 @@ oo::class create tdbc::resultset {
 	    if {[info exists broken] || ![my nextresults]} {
 		break
 	    }
-	}	
+	}
 
 	return
     }
 
-    
+
     # The 'nextrow' method retrieves a row in the form of either
     # a list or a dictionary.
 
@@ -833,9 +834,9 @@ oo::class create tdbc::resultset {
 
 	set opts [dict create -as dicts]
 	set i 0
-    
+
 	# Munch keyword options off the front of the command arguments
-	
+
 	foreach {key value} $args {
 	    if {[string index $key 0] eq {-}} {
 		switch -regexp -- $key {
@@ -851,7 +852,7 @@ oo::class create tdbc::resultset {
 			lappend errorcode badOption $key
 			return -code error -errorcode $errorcode \
 			    "bad option \"$key\":\
-                             must be -as or -columnsvariable"
+			     must be -as or -columnsvariable"
 		    }
 		}
 	    } else {
@@ -866,7 +867,7 @@ oo::class create tdbc::resultset {
 	    lappend errorcode wrongNumArgs
 	    return -code error -errorcode $errorcode \
 		"wrong # args: should be [lrange [info level 0] 0 1]\
-                 ?-option value?... ?--? varName"
+		 ?-option value?... ?--? varName"
 	}
 	upvar 1 [lindex $args 0] row
 	if {[dict get $opts -as] eq {lists}} {
@@ -899,7 +900,7 @@ oo::class create tdbc::resultset {
 
     # Derived classes are expected to implement the following methods:
 
-    # constructor and destructor.  
+    # constructor and destructor.
     #        Constructor accepts a statement and an optional
     #        a dictionary of substituted parameters  and
     #        executes the statement against the database. If
