@@ -6,10 +6,10 @@
 #
 # Copyright (c) 1998-2000 by Scriptics Corporation.
 # All rights reserved.
-# 
+#
 # RCS: @(#) $Id$
 
-package require Tcl 8.6
+package require Tcl 8.5-
 package require tcltest 2.2
 ::tcltest::configure \
     -testdir [file dirname [file normalize [info script]]] \
